@@ -33,7 +33,7 @@ class FileInterface():
             }
         }, ignore_extra_keys=True, description= "File Interface Schema")
     
-    def __init__(self, intf_path = "C:/Users/{0}/AppData/Roaming/PYJSX/INTFS/".format(Utils.get_user())):
+    def __init__(self, intf_path = "C:/Users/{0}/AppData/Roaming/PYJSX/INTFS/intf1.json".format(Utils.get_user())):
 
         self.value = self._default_value
         self.path = intf_path
@@ -50,8 +50,8 @@ class FileInterface():
 
     # [GRABBERS]
     def grab_raw(self):
-            with open(self.path, 'r') as f: c = f.read()
-            return c
+        with open(self.path, 'r') as f: c = f.read()
+        return c
 
     def grab_proper(self):
 
